@@ -25,16 +25,14 @@ getTempDir = function() {
   file.path(getWorkDir(), basename(tempfile("tmp")))
 }
 
-makeTestRegistry = function(packages=character(0L), ...) {
-  work.dir = getWorkDir()
-  file.dir = getTempDir()
-  dir.create(file.dir, recursive=TRUE, showWarning=FALSE)
+makeTestRegistry = function(packages = character(0L), work.dir = getWorkDir(), file.dir = getTempDir(), ...) {
+  dir.create(file.dir, recursive = TRUE, showWarning = FALSE)
   makeRegistry(
     id = "unittests",
     seed = 1L,
-    packages=packages,
-    file.dir=file.dir,
-    work.dir=work.dir,
+    packages = packages,
+    file.dir = file.dir,
+    work.dir = work.dir,
     ...
   )
 }
